version 11.0
#delimit ;
log using "C:\matt\publications\jop2\webpage\interaction2.log", replace;
set more off;

*     ***************************************************************** *;
*     ***************************************************************** *;
*       File-Name:      interaction2.do                                 *;
*       Date:           1/7/2013                                        *;
*       Author:         MG                                              *;
*       Purpose:        Do-file to produce a marginal effect plot for   *;
*                       X when the interaction model is:                *;
*                       Y = b0 + b1X + b2W + b3Z + b4XW + b5XZ + b6WZ   *;
*                       b7XWZ + e                                       *;
*       Input File:     interaction2.dta                                *;
*       Output File:    interaction2.log                                *;
*       Data Output:    None	                                        *;
*       Previous file:  None                                            *;
*       Machine:        laptop                                          *;
*     ****************************************************************  *;
*     ****************************************************************  *;

use "C:\matt\publications\jop2\webpage\interaction2.dta", clear;

*     ****************************************************************  *;
*     ****************************************************************  *;
*	  Get stuff ready to produce a marginal effect for X.               *;
*     ****************************************************************  *;
*     ****************************************************************  *;

set obs 1000;

regress  legislative_parties fragmentation concentration logmagnitude 
        fragmentation_concentration logmagnitude_fragmentation 
        logmag_concentration frag_conc_logmag 
        proximity presidential_candidate proximity_presidential_candidate, robust;

matrix b=e(b);
matrix V=e(V);
scalar b1=b[1,1];
scalar b2=b[1,2];
scalar b3=b[1,3];
scalar b4=b[1,4];
scalar b5=b[1,5];
scalar b6=b[1,6];
scalar b7=b[1,7];

scalar varb1=V[1,1];
scalar varb2=V[2,2];
scalar varb3=V[3,3];
scalar varb4=V[4,4];
scalar varb5=V[5,5];
scalar varb6=V[6,6];
scalar varb7=V[7,7];

scalar covb1b4=V[1,4];
scalar covb1b5=V[1,5];
scalar covb1b7=V[1,7];
scalar covb4b5=V[4,5];
scalar covb4b7=V[4,7];
scalar covb5b7=V[5,7];

scalar list b1 b2 b3 b4 b5 b6 b7 varb1 varb2 varb3 varb4 varb5 varb6 varb7 
            covb1b4 covb1b5 covb1b7 covb4b5 covb4b7 covb5b7;

*     ****************************************************************  *;
*       Calculate data necessary for top marginal effect plot.          *;
*     ****************************************************************  *;

generate MVZ=((_n-1)/10);
replace MVZ=. if _n>30;

*     ****************************************************************  *;
*       We want to calculate the marginal effect of X on Y for all      *;
*       values of the modifying variable Z. We also want to calculate   *;
*       this marginal effect as Z changes for specific values of the    *;
*       second modifying variable W.  In the code below, we calculate   *;
*       the marginal effect of X on Y for all values of Z when W=0,     *;
*       when W=1, when W=2, and when W=3.                               *;
*     ****************************************************************  *;

gen conb0=b1+b4*0+b5*MVZ+b7*(0*MVZ) if _n<30;
gen conb1=b1+b4*1+b5*MVZ+b7*(1*MVZ) if _n<30;
gen conb2=b1+b4*2+b5*MVZ+b7*(2*MVZ) if _n<30;
gen conb3=b1+b4*3+b5*MVZ+b7*(3*MVZ) if _n<30;
gen conb4=b1+b4*4+b5*MVZ+b7*(4*MVZ) if _n<30;

*     ****************************************************************  *;
*       Calculate the standard errors for the marginal effect of X on Y *;
*     ****************************************************************  *;

gen conse0=sqrt(varb1
                + varb4*(0^2) + varb5*MVZ^2 + varb7*MVZ^2*(0^2)
                + 2*0*covb1b4 + 2*MVZ*covb1b5 + 2*0*MVZ*covb1b7+2*0*MVZ*covb4b5
                + 2*(0^2)*MVZ*covb4b7 + 2*0*(MVZ^2)*covb5b7)  if _n<30;
                
gen conse1=sqrt(varb1
                + varb4*(1^2) + varb5*MVZ^2 + varb7*MVZ^2*(1^2)
                + 2*1*covb1b4 + 2*MVZ*covb1b5 + 2*1*MVZ*covb1b7+2*1*MVZ*covb4b5
                + 2*(1^2)*MVZ*covb4b7 + 2*1*(MVZ^2)*covb5b7)  if _n<30;
                
gen conse2=sqrt(varb1
                + varb4*(2^2) + varb5*MVZ^2 + varb7*MVZ^2*(2^2)
                + 2*2*covb1b4 + 2*MVZ*covb1b5 + 2*2*MVZ*covb1b7+2*2*MVZ*covb4b5
                + 2*(2^2)*MVZ*covb4b7 + 2*2*(MVZ^2)*covb5b7)  if _n<30;
                
gen conse3=sqrt(varb1
                + varb4*(3^2) + varb5*MVZ^2 + varb7*MVZ^2*(3^2)
                + 2*3*covb1b4 + 2*MVZ*covb1b5 + 2*3*MVZ*covb1b7+2*3*MVZ*covb4b5
                + 2*(3^2)*MVZ*covb4b7 + 2*3*(MVZ^2)*covb5b7)  if _n<30;
                
gen conse4=sqrt(varb1
                + varb4*(4^2) + varb5*MVZ^2 + varb7*MVZ^2*(4^2)
                + 2*4*covb1b4 + 2*MVZ*covb1b5 + 2*4*MVZ*covb1b7+2*4*MVZ*covb4b5
                + 2*(4^2)*MVZ*covb4b7 + 2*4*(MVZ^2)*covb5b7)  if _n<30;
                
*     ****************************************************************  *;
*                           Create t statistics                         *;
*     ****************************************************************  *;

gen t0=conb0/conse0;
gen t1=conb1/conse1;
gen t2=conb2/conse2;
gen t3=conb3/conse3;
gen t4=conb4/conse4;

*     ****************************************************************  *;
*       Generate a `shadow' variable that is equal to the marginal      *;
*       effects that have already been calculated.  These will be       *;
*       helpful in placing the stars in the figure as you will see.     *;
*     ****************************************************************  *;

gen consb0=conb0;
gen consb1=conb1;
gen consb2=conb2;
gen consb3=conb3;
gen consb4=conb4;

*     ****************************************************************  *;
*       Make the `shadow' variable be missing if the t score is not     *;
*       larger than the critical level of significance that you want.   *;
*     ****************************************************************  *;

replace consb0 = . if abs(t0)<2.01;
replace consb1 = . if abs(t1)<2.01;
replace consb2 = . if abs(t2)<2.01;
replace consb3 = . if abs(t3)<2.01;
replace consb4 = . if abs(t4)<2.01;

*     ****************************************************************  *;
*       Generate a string variable called str1 that is designated with  *;
*       a star.                                                         *;
*     ****************************************************************  *;

generate str1 txt="*";

set textsize 100;

*     ****************************************************************  *;
*       Graph the effect of fragmentation on legislative parties        *;
*       conditional on logmag                                           *;
*     ****************************************************************  *;

graph twoway line conb0 MVZ, clpattern(solid) clwidth(thin) 
        || scatter consb0 MVZ, mlabel(txt) msymbol(i) mlabsize(vsmall) mlabgap(-1.0) mlabposition(11)  
        || line conb1 MVZ, clpattern(solid) clwidth(thin)  
        || scatter consb1 MVZ, mlabel(txt) msymbol(i) mlabsize(vsmall) mlabgap(-1.0) mlabposition(11)  
        || line conb2 MVZ, clpattern(solid) clwidth(thin) 
        || scatter consb2 MVZ, mlabel(txt) msymbol(i) mlabsize(vsmall) mlabgap(-1.0) mlabposition(11) 
        || line conb3 MVZ, clpattern(solid) clwidth(thin)  
        || scatter consb3 MVZ, mlabel(txt) msymbol(i) mlabsize(vsmall) mlabgap(-1.0) mlabposition(11)          
        || ,       
        xlabel(0 0.5 1 1.5  2 2.5 3, nogrid labsize(2.5))   
        ylabel(-0.4 -0.2 0 0.2 0.4 0.6 0.8, nogrid labsize(2.5))  
        yscale(noline)  xscale(noline)  legend(off)  
        yline(0, lcolor(black))   
        xtitle("Logged Average District Magnitude")  
        ytitle("Marginal Effect of Fragmentation")  
        xsca(titlegap(4)) ysca(titlegap(4)) 
        scheme(s2mono) graphregion(fcolor(white) ilcolor(white) lcolor(white));

log close;

